@@ -8,5 +8,5 @@ class TestMLExtraction(TestCase):
     def test__mock_features_and_labels(self):
         df = TEST_DF.copy()
 
-        self.assertEqual(len(df.ml.extract(lambda df: df["Close"])), len(df))
+        self.assertEqual(len(df._.extract(lambda df: df["Close"])), len(df))
 
